library(shiny)
library(tidyverse)

# Create a Shiny application using the sidebarLayout and the iris dataset
# 
# 1 a. In the sidebarPanel, create radio buttons to select between sepal length,
#     sepal width, petal length and petal width
# 
#   b. In the main panel, create a barplot showing the attribute selected from the radio buttons
#     for the 3 different species. 
# 
#   c. Add a textInput to allow the user to name the plot
# 
# 
# 2 a. Show the iris data in table format below the plot
# 
#   b. In the sidebar, allow the user to select the number of rows to be shown
#      in the table
# 
# [Optional]
# 3 a. Put the plot and table in separate tabs
#   b. Add another tab with a table showing the mean and standard deviation 
# for the selected attribute

iris_categories <- colnames(dplyr::select(iris, -Species))

ui <- fluidPage(
  
  titlePanel("Exercise 5"),
  
  sidebarLayout(
    sidebarPanel(  
      radioButtons(inputId = "plotting_attribute", 
                   label   = "Select attribute to plot", 
                   choices = iris_categories),
      textInput(inputId = "plot_name", label = "Enter plot name"),
      numericInput("n_rows", value = 6, min = 0, label = "Number of rows in table")
    ),
    
    mainPanel(
      tabsetPanel(
        tabPanel("plot",
                 br(),
                 plotOutput(outputId = "iris_plot")
        ),
        tabPanel("data table",
                 br(),
                 tableOutput(outputId = "table_data"),
        ),
        tabPanel("mean",
                 br(),
                 h4(textOutput("stat_summary_title")),
                 tableOutput(outputId = "stat_summary")
        )
      )  
    )
  )#,
  #actionButton("browser", "browser")
)


server <- function(input, output, session) {
  
  output$iris_plot <- renderPlot({
    
    iris %>%
      ggplot(aes(x = Species, y = .data[[input$plotting_attribute]], fill = Species)) +
      geom_boxplot() +
      ggtitle(input$plot_name) +
      theme(legend.position = "none")
  })
  
  output$table_data <- renderTable({
    
    iris %>%
      head(n = input$n_rows)

  })
  
  output$stat_summary <- renderTable({
     iris %>%
       group_by(Species) %>%
       summarise(mean_value = mean(.data[[input$plotting_attribute]]), sd = sd(.data[[input$plotting_attribute]]))
   })

  output$stat_summary_title <- renderText({
    paste0("Data summary for ", input$plotting_attribute) 
  })
  
  
  observeEvent(input$browser, {
    browser()
  })
  
}

shinyApp(ui, server)

